/**********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO
* THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2019 Renesas Electronics Corporation. All rights reserved.
*********************************************************************************************************************/
/**********************************************************************************************************************
* File Name    : MotionSensor.c
* Version      : 1.00
* Description  : Sample program of the e-AI inference application.
*********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 14.06.2019 1.00     First Release
*********************************************************************************************************************/

/**********************************************************************************************************************
Includes   <System Includes> , "Project Includes"
*********************************************************************************************************************/
/* System include */
#include <string.h>
#include <stdio.h>
#include <stdint.h>
#include <float.h>
#include <math.h>
#include "r_smc_entry.h"
#include "iodefine.h"

/* Motor control include */
#include "r_mtr_common.h"
#include "r_mtr_foc_control_less_speed.h"

/* RX DSP Library include */
#include "r_dsp_types.h"
#include "r_dsp_transform.h"
#include "r_dsp_statistical.h"
#include "r_dsp_complex.h"

/* e-AI Translator include */
#include "Typedef.h"
#include "layer_graph.h"

/* e-AI application include */
#include "MotionSensor.h"
#include "r_fft_window_coefficient.h"

/**********************************************************************************************************************
Macro definitions
*********************************************************************************************************************/
#define AI_INPUT_SIZE (50)

/**********************************************************************************************************************
Local Typedef definitions
*********************************************************************************************************************/

/**********************************************************************************************************************
Exported global variables
*********************************************************************************************************************/
extern mtr_foc_control_t g_st_foc;
extern uint16_t com_u2_mtr_pp;
extern float g_current;
extern TPrecision *dnn_compute (TPrecision *);

/**********************************************************************************************************************
Private (static) variables and functions
*********************************************************************************************************************/
/* A/D sampling ring buffer */
ST_SamplingRingBuffer gv_SamplingRingBuffer;

/* A/D sampling rign counter (0 - 959) */
volatile uint16_t gv_SamplingCounter;
/* A/D 1 frame end */
volatile uint16_t gv_FrameSamplingEnd;
/* A/D0 conversion results buffer  */
int16_t gv_AD0Bffer[(DEF_MaxSamplingCount * 2) - DEF_MinOverlapSampling];
/* A/D1 conversion results buffer */
int16_t gv_AD1Bffer[(DEF_MaxSamplingCount * 2) - DEF_MinOverlapSampling];
/* A/D2 conversion results buffer */
int16_t gv_AD2Bffer[(DEF_MaxSamplingCount * 2) - DEF_MinOverlapSampling];

/* FTDI send status */
uint16_t gv_RspiSendStatus;

/* For FFT */
/* A/D value buffer for window function */
static int32_t gs_fft_VecCplxMagi32[DEF_MaxSamplingCount / 2];
/* " Storage area for operation results of "R_DSP_FFT_i16ci32" function (No. of samplings/2) */
static cplxi32_t gs_fft_buf[(DEF_MaxSamplingCount / 2)];
/*// "Argument for "R_DSP_FFT_i16ci32" function(display input buffer)  */
static vector_t gs_fft_time =
{ DEF_MaxSamplingCount, NULL };
/* "Argument for "R_DSP_FFT_i16ci32" function(display output buffer)  */
static vector_t gs_fft_freq =
{ (DEF_MaxSamplingCount / 2), gs_fft_buf };
/* "Argument for "R_DSP_VecCplxMag_ci32i32" function (display output buffer)  */
static vector_t gs_fft_mag =
{ (DEF_MaxSamplingCount / 2), gs_fft_VecCplxMagi32 };
/* FFT function handle (default option)  */
static r_dsp_fft_t gs_fft_handle =
{ DEF_MaxSamplingCount, 0 };
/* Rotation factor buffer */
static int16_t gs_fft_twiddles[(DEF_MaxSamplingCount + (DEF_MaxSamplingCount / 2))];
/* Bit reverse buffer */
static int32_t gs_fft_bitrev[DEF_FFT_NUM_BITREV];

/* 12bit A/D full scale value in dB units */
float gv_DecibelsBelowFullScale;

/* (No. of samplings/2)**2 */
float gv_SquareSamplingHalf;

uint16_t gv_MonitorStatus;

/* Monitor send data area */
ST_SamplingMonitor gv_SamplingMonitor;

/* Receive data (dummy)  */
uint8_t gv_RecvData;

/* Receive ring buffer */
ST_PcRecvRingBuffer gv_PcRecvRingBuffer;

/* Receive status */
uint16_t gv_PcRecvStatus;

/* Receive command  */
uint8_t gv_PcCommand;

/* Receive monitor timer  */
uint32_t gv_PcRecvTimer;

/* Sampling conditions */
ST_SamplingConditions gv_SamplingConditions;

/* Sampling  buffer size */
uint16_t gv_SamplingSize;

/*  Sampling buffer #2 -> #1 overlap position */
uint16_t gv_Buffer2to1Overlap;

/* Even frame end position */
uint16_t gv_Frame1End;

/* Odd frame end position */
uint16_t gv_Frame2End;

/* Moving average */
ST_MovingAverage gv_MovingAverage;

/* Send header data */
static const uint8_t lc_Header[DEF_HeaderSize] =
{ 0xFF, 0xAA, 0x55, 0x00, 0xFA, 0xF5, 0xAF };

static void fGetAdData (void);
static void fSetADSendData (int16_t Ad0Value, int16_t Ad1Value, int16_t Ad2Value);
static void fCalcFrequencySpectrum (void);
static void fExecuteFFT (int16_t *pInBuf, float *pOutBuf);
static void fInitFft (void);
static void fGetMotorData (float *pRotationSpeed, float *pPeekCurrent);
static void fSendFtdi (uint8_t *pSendBuffer, uint16_t Size);
static void fPcCommandRecv (void);
static uint8_t fPcGetData (uint8_t *pBuff);
static void fUpadteMovingAverage (uint16_t AiInference);
static float fGetMovingAverage (void);
static int8_t AI_Inference (uint16_t SamplingCount, float *pSpectrumX);

/**********************************************************************************************************************
* Function Name: MotionSensorInit
* Description  : Motion sensor process initialization
* Arguments    : none
* Return Value : none
*********************************************************************************************************************/
void MotionSensorInit (void)
{
    gv_SamplingCounter = 0;
    gv_FrameSamplingEnd = 0;
    memset( &gv_SamplingRingBuffer, 0, sizeof(gv_SamplingRingBuffer));
    memset( &gv_SamplingMonitor, 0, sizeof(gv_SamplingMonitor));
    memset( &gv_PcRecvRingBuffer, 0, sizeof(gv_PcRecvRingBuffer));
    gv_RspiSendStatus = 0;
    gv_MonitorStatus = 0;
    gv_PcRecvStatus = 0;
    gv_PcCommand = 0;
    gv_PcRecvTimer = 0;
    
    memcpy( &gv_SamplingMonitor.m_Header, lc_Header, DEF_HeaderSize);
    
    /* Initialize the A/D full scale value in dB */
    gv_DecibelsBelowFullScale = 10.0 * log10f(pow(pow(2, 12), 2));
    
    /* Default sampling setting */
    gv_SamplingConditions.m_SamplingFrequency = DEF_DefaultSamplingFrequency;
    gv_SamplingConditions.m_SamplingCount = DEF_DefaultSamplingCount;
    gv_SamplingConditions.m_SamplingOverLap = DEF_DefaultOverlapSampling;
    
    /* Default moving average count */
    gv_SamplingConditions.m_MovingAverageMaxCount = DEF_DefaultMovingAverageMaxCount;
    
    /* Initialize sampling mode  */
    gv_SamplingConditions.m_SamplingMode = DEF_ShuntCurrentSampling;
    
    /* Initialize FFT process */
    fInitFft();
    
    /* Start IRQ1 */
    R_Config_ICU_IRQ1_Start();
    
    /* Start SCI8 */
    R_Config_SCI8_Start();
    
    /* Start SCI8 receive */
    R_Config_SCI8_Serial_Receive( &gv_RecvData, 1);
}
/**********************************************************************************************************************
* End of function MotionSensorInit
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: MotionSensorMonitor
* Description  : Motion sensor monitor processing 
* Arguments    : none
* Return Value : none
*********************************************************************************************************************/
void MotionSensorMonitor (void)
{
    /* Analyze PC command */
    fPcCommandRecv();
    
    /* Start measurement */
    if (DEF_StartMonitor == gv_PcCommand)
    {
        /* Clear request */
        gv_PcCommand = 0;
        
        /* Setting during measurement */
        gv_MonitorStatus = 1;
        
        /* Moving average initialization */
        memset( &gv_MovingAverage, 0, sizeof(gv_MovingAverage));
        gv_MovingAverage.m_MaxCount = gv_SamplingConditions.m_MovingAverageMaxCount;
        
        /* Sampling number initialization */
        gv_SamplingCounter = 0;
        
        /* Start CMT1 count */
        R_Config_CMT1_Start();
    }
    else if (DEF_StopMonitor == gv_PcCommand)
    {
        /* Clear request */
        gv_PcCommand = 0;
        
        /* Setting when not calculating */
        gv_MonitorStatus = 0;
        
        /* Stop CMT1 count */
        R_Config_CMT1_Stop();
    }
    else
    {
        /* No operation */
    }
    
    /* Get A/D conversion result and AI inference value  */
    fGetAdData();

}
/**********************************************************************************************************************
* End of function MotionSensorMonitor
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: AI_Inference
* Description  : Data preprocess and AI Inference
* Arguments    : uint16_t SamplingCount
*                float    *pSpectrumX
*                float    *pSpectrumY
* Return Value : int8_t   AI Inference result (0 - 100)
*********************************************************************************************************************/
static int8_t AI_Inference (uint16_t SamplingCount, float *pSpectrumX)
{
    TPrecision *p_prediction;
    int8_t AIresult;
    TsInt i;
    static float data_in[AI_INPUT_SIZE];

    /* The pre-processing function and dnn_compute function are called */
    for(i=0; i < AI_INPUT_SIZE; i++)
    {
        data_in[i] = pSpectrumX[i+1];
    }

    /* Call e-AI inference function */
    p_prediction = dnn_compute(data_in);
    AIresult = (int8_t) ((p_prediction[1] * 100) + 0.5);

    return AIresult;
}
/**********************************************************************************************************************
* End of function AI_Inference
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fGetAdData
* Description  : A/D conversion value acquisition
* Arguments    : none
* Return Value : none
*********************************************************************************************************************/
static void fGetAdData (void)
{
    int16_t AD0Value;
    int16_t AD1Value;
    int16_t AD2Value;
    
    /* Data send not in process */
    if (0 == gv_RspiSendStatus)
    {
        /* Get 1 frame of data */
        if (0 != gv_FrameSamplingEnd)
        {
            /* Get frequency spectrum  */
            fCalcFrequencySpectrum();
        }
        else
        {
            /* Conversion result is in ring buffer  */
            if (gv_SamplingRingBuffer.m_Read != gv_SamplingRingBuffer.m_Write)
            {
                /* Get conversion value from ring buffer */
                AD0Value = gv_SamplingRingBuffer.m_SamplingRingData[gv_SamplingRingBuffer.m_Read].m_Ad0Value;
                AD1Value = gv_SamplingRingBuffer.m_SamplingRingData[gv_SamplingRingBuffer.m_Read].m_Ad1Value;
                AD2Value = gv_SamplingRingBuffer.m_SamplingRingData[gv_SamplingRingBuffer.m_Read].m_Ad2Value;
                
                /* Update read pointer */
                gv_SamplingRingBuffer.m_Read = (uint16_t) ((gv_SamplingRingBuffer.m_Read + 1)
                        & (DEF_SamplingRingBuffer - 1));
                
                /* Create A/D conversion result send data */
                fSetADSendData(AD0Value, AD1Value, AD2Value);
                
                gv_AD0Bffer[gv_SamplingCounter] = AD0Value;
                gv_AD1Bffer[gv_SamplingCounter] = AD1Value;
                gv_AD2Bffer[gv_SamplingCounter] = AD2Value;
                
                /* Overlap area of sampling buffer #2 and sampling buffer #1 start areas  */
                if (gv_SamplingCounter >= gv_Buffer2to1Overlap)
                {
                    gv_AD0Bffer[gv_SamplingCounter - gv_Buffer2to1Overlap] = AD0Value;
                    gv_AD1Bffer[gv_SamplingCounter - gv_Buffer2to1Overlap] = AD1Value;
                    gv_AD2Bffer[gv_SamplingCounter - gv_Buffer2to1Overlap] = AD2Value;
                }
                
                /* End of 1 frame */
                if (gv_SamplingCounter == gv_Frame1End)
                {
                    /* Frame #1 sampling end */
                    gv_FrameSamplingEnd = DEF_FrameSamplingEnd1;
                }
                else if (gv_SamplingCounter == gv_Frame2End)
                {
                    /* Frame #2 sampling end */
                    gv_FrameSamplingEnd = DEF_FrameSamplingEnd2;
                }
                else
                {
                    /* No operation */
                }
                
                /* Update sampling counter */
                gv_SamplingCounter++;
                
                /* Read end  */
                if (gv_SamplingCounter >= gv_SamplingSize)
                {
                    /* Set to position after overlap area */
                    gv_SamplingCounter = gv_SamplingConditions.m_SamplingOverLap;
                }
            }
        }
    }
}
/**********************************************************************************************************************
* End of function fGetAdData
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fSetADSendData
* Description  : Send A/D conversion results to PC
* Arguments    : int16_t Ad0Value  : A/D0 conversion result
*                int16_t Ad1Value  : A/D1 conversion result
*                int16_t Ad2Value  : A/D2 conversion result
* Return Value : none
*********************************************************************************************************************/
static void fSetADSendData (int16_t Ad0Value, int16_t Ad1Value, int16_t Ad2Value)
{
    uint16_t Size;
    
    /* PC command */
    gv_SamplingMonitor.m_Cmd = DEF_SendAdMonitor;
    
    /*  Store A/D conversion value in send buffer */
    gv_SamplingMonitor.UN_Sampling.m_SamplingData.m_Ad0Value = Ad0Value;
    gv_SamplingMonitor.UN_Sampling.m_SamplingData.m_Ad1Value = Ad1Value;
    gv_SamplingMonitor.UN_Sampling.m_SamplingData.m_Ad2Value = Ad2Value;
    
    Size = sizeof(ST_SamplingRingData) + DEF_HeaderSize + 1;
    
    /* Send A/D value */
    fSendFtdi((uint8_t *) &gv_SamplingMonitor, Size);
}
/**********************************************************************************************************************
* End of function fSetADSendData
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fCalcFrequencySpectrum
* Description  : Execute FFT operation to get frequency spectrum
* Arguments    : none
* Return Value : none
*********************************************************************************************************************/
static void fCalcFrequencySpectrum (void)
{
    int32_t Top;
    uint16_t Size;
    int8_t AiResult;
    
    if (DEF_FrameSamplingEnd1 == gv_FrameSamplingEnd)
    {
        Top = 0;
    }
    else
    {
        Top = gv_SamplingConditions.m_SamplingCount - gv_SamplingConditions.m_SamplingOverLap;
    }
    
    gv_FrameSamplingEnd = 0;
    
    gv_SamplingMonitor.m_Cmd = DEF_SendFrequencyMonitor;
    
    /* Execute FFT operation, get frequency spectrum */
    if (DEF_SamplingCount128 == gv_SamplingConditions.m_SamplingCount)
    {
        fExecuteFFT( &gv_AD0Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_FrequencySpectrum[0]);
        fExecuteFFT( &gv_AD1Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_FrequencySpectrum[1]);
        fExecuteFFT( &gv_AD2Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_FrequencySpectrum[2]);
        
        /* Get rotational speed and peak current of the motor */
        fGetMotorData( &gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_RotationSpeed,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_PeekCurrent);
        
        /* Get AI inferenced value */
        AiResult = AI_Inference(DEF_SamplingCount128,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_FrequencySpectrum[0][0]);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_AiResult = AiResult;
        
        if (0 == gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_RotationSpeed)
        {
            AiResult = 0;
        }
        
        fUpadteMovingAverage((uint16_t) AiResult);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling128.m_AiMovingAverage = fGetMovingAverage();
        
        Size = sizeof(ST_Sampling128) + DEF_HeaderSize + 1;
    }
    else if (DEF_SamplingCount256 == gv_SamplingConditions.m_SamplingCount)
    {
        fExecuteFFT( &gv_AD0Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_FrequencySpectrum[0]);
        fExecuteFFT( &gv_AD1Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_FrequencySpectrum[1]);
        fExecuteFFT( &gv_AD2Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_FrequencySpectrum[2]);
        
        /* Get rotational speed and peak current of the motor */
        fGetMotorData( &gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_RotationSpeed,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_PeekCurrent);
        
        /* Get AI inferenced value */
        AiResult = AI_Inference(DEF_SamplingCount256,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_FrequencySpectrum[0][0]);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_AiResult = AiResult;
        
        if (0 == gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_RotationSpeed)
        {
            AiResult = 0;
        }
        
        fUpadteMovingAverage((uint16_t) AiResult);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling256.m_AiMovingAverage = fGetMovingAverage();
        
        Size = sizeof(ST_Sampling256) + DEF_HeaderSize + 1;
    }
    else if (DEF_SamplingCount512 == gv_SamplingConditions.m_SamplingCount)
    {
        fExecuteFFT( &gv_AD0Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_FrequencySpectrum[0]);
        fExecuteFFT( &gv_AD1Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_FrequencySpectrum[1]);
        fExecuteFFT( &gv_AD2Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_FrequencySpectrum[2]);
        
        /* Get rotational speed and peak current of the motor */
        fGetMotorData( &gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_RotationSpeed,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_PeekCurrent);
        
        /* Get AI inferenced value */
        AiResult = AI_Inference(DEF_SamplingCount512,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_FrequencySpectrum[0][0]);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_AiResult = AiResult;
        
        if (0 == gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_RotationSpeed)
        {
            AiResult = 0;
        }
        
        fUpadteMovingAverage((uint16_t) AiResult);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling512.m_AiMovingAverage = fGetMovingAverage();
        
        Size = sizeof(ST_Sampling512) + DEF_HeaderSize + 1;
    }
    else
    {
        fExecuteFFT( &gv_AD0Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_FrequencySpectrum[0]);
        fExecuteFFT( &gv_AD1Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_FrequencySpectrum[1]);
        fExecuteFFT( &gv_AD2Bffer[Top], gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_FrequencySpectrum[2]);
        
        /* Get rotational speed and peak current of the motor */
        fGetMotorData( &gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_RotationSpeed,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_PeekCurrent);
        
        /* Get AI inferenced value */
        AiResult = AI_Inference(DEF_SamplingCount1024,
                &gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_FrequencySpectrum[0][0]);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_AiResult = AiResult;
        
        if (0 == gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_RotationSpeed)
        {
            AiResult = 0;
        }
        
        fUpadteMovingAverage((uint16_t) AiResult);
        
        gv_SamplingMonitor.UN_Sampling.m_Sampling1024.m_AiMovingAverage = fGetMovingAverage();
        
        Size = sizeof(ST_Sampling1024) + DEF_HeaderSize + 1;
    }
    
    /* Send frequency spectrum value */
    fSendFtdi((uint8_t *) &gv_SamplingMonitor, Size);
}
/**********************************************************************************************************************
* End of function fCalcFrequencySpectrum
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fExecuteFFT
* Description  : Execute FFT operation
* Arguments    : int16_t *pInBuf  : Pointer to the A/D sampling buffer 
*                float *pOutBuf   : Pointer to the frequency spectrum buffer
* Return Value : none
*********************************************************************************************************************/
static void fExecuteFFT (int16_t *pInBuf, float *pOutBuf)
{
    uint32_t i;
    uint16_t SamplingHalf = gv_SamplingConditions.m_SamplingCount / 2;
    
    gs_fft_time.data = pInBuf;
    
    /* Real FFT transformation (output FFT result as a complex number)  */
    R_DSP_FFT_i16ci32( &gs_fft_handle, &gs_fft_time, &gs_fft_freq);
    
    /*
     * Obtain complex magnitude value
     * Analysis conditions when FFT length is 512 and the sampling frequency is 2kHz
     *  - frequency ticks: 2000Hz / 512 = 3.90625Hz)
     *  - Measurable frequency: 3.90625Hz * 255 = 996.09375Hz
     */
    R_DSP_VecCplxMag_ci32i32( &gs_fft_freq, &gs_fft_mag, SamplingHalf);
    
    /*
     * Replace 0th element of calculation result with gs_fft_buf[0].re
     * This process is necessary to remove the influence of real number half of the FFT length.
     */
    *(int32_t *) gs_fft_mag.data = gs_fft_buf[0].re;
    
    /*
     * Convert to dBFS(decibels below full scale)
     * Step1 : Convert fixed point number (1Q15) to floating point number.
     *         Divide FFT library output result (stored in int32 gs_fft_VecCplxMagi32[]) by (2^15-1).
     *         It is half the amplitude of the A/D full scale value.
     * Step2 : Double the result of step1 to get full amplitude of A/D full scale value
     * Step3 : Convert the result of step 2 to voltage-ratio(dB).
     * Step4 : Subtract 12bit A/D full scale voltage-ratio (72.247199 dB) to convert to dBFS.
     * Note : The maximum magnitude that can be used for dBFS is 0dBFS.
     * If an magnitude lower than this is used, a negative number will be displayed.
     */
    
    for (i = 0; i < SamplingHalf; i++)
    {
        if (0 != gs_fft_VecCplxMagi32[i])
        {
            pOutBuf[i] = (20.0 * log10f((float) gs_fft_VecCplxMagi32[i] / 16383)) - gv_DecibelsBelowFullScale;
        }
        /* When the complex absolute value is 0 */
        else
        {
            pOutBuf[i] = -gv_DecibelsBelowFullScale;
        }
    }
}
/**********************************************************************************************************************
* End of function fExecuteFFT
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fInitFft
* Description  : RX DSP library FFT process initialization
* Arguments    : none
* Return Value : none
*********************************************************************************************************************/
static void fInitFft (void)
{
    uint16_t Count;
    
    /* Initialize FFT handle data */
    gs_fft_handle.n = gv_SamplingConditions.m_SamplingCount;
    gs_fft_handle.work = NULL;
    gs_fft_handle.options = (R_DSP_FFT_OPT_SCALE | R_DSP_FFT_BIT_REVERSAL_DEFAULT | R_DSP_FFT_OPT_TWIDDLE_DEFAULT);
    gs_fft_handle.bitrev = gs_fft_bitrev;
    gs_fft_handle.twiddles = gs_fft_twiddles;
    gs_fft_handle.window = NULL;
    
    gs_fft_time.n = gv_SamplingConditions.m_SamplingCount;
    gs_fft_freq.n = gv_SamplingConditions.m_SamplingCount / 2;
    gs_fft_mag.n = gv_SamplingConditions.m_SamplingCount / 2;
    
    /* Set window coefficient according to FFT length */
      switch(gv_SamplingConditions.m_SamplingCount)
    {
        case DEF_SamplingCount1024:
            gs_fft_handle.window = (void *) i16_hanning_fft1024;
            break;
        case DEF_SamplingCount512:
            gs_fft_handle.window = (void *) i16_hanning_fft512;
            break;
        case DEF_SamplingCount256:
            gs_fft_handle.window = (void *) i16_hanning_fft256;
            break;
        case DEF_SamplingCount128:
            gs_fft_handle.window = (void *) i16_hanning_fft128;
            break;
        default:
            gs_fft_handle.window = NULL;
            break;
    }

    /* Initialize FFT */
    R_DSP_FFT_Init_i16ci32( &gs_fft_handle);
    
    /* Sampling size */
    gv_SamplingSize = (gv_SamplingConditions.m_SamplingCount * 2) - gv_SamplingConditions.m_SamplingOverLap;

    /* Overlap area of sampling buffer #2 and sampling buffer #1 start areas  */
    gv_Buffer2to1Overlap = gv_SamplingSize - gv_SamplingConditions.m_SamplingOverLap;

    /* End position of #1 frame  */
    gv_Frame1End = gv_SamplingConditions.m_SamplingCount - 1;

    /* End position of #2 frame  */
    gv_Frame2End = gv_SamplingSize - 1;
    
    /* (Sampling count/2)**2    */
    gv_SquareSamplingHalf = (float) ((gv_SamplingConditions.m_SamplingCount / 2)
            * (gv_SamplingConditions.m_SamplingCount / 2));
    
    /* Sampling frequency */
    Count = (uint16_t) (DEF_CMT_CLK8 / (float) (gv_SamplingConditions.m_SamplingFrequency)) - 1;
    
    /* A/D conversion trigger timer setting */
    CMT1.CMCOR = Count;
}
/**********************************************************************************************************************
* End of function fInitFft
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fGetMotorData
* Description  : Get motor data
* Arguments    : float *pRotationSpeed   : Rotation speed
*                float *pPeekCurrent     : Peak current
* Return Value : none
*********************************************************************************************************************/
static void fGetMotorData (float *pRotationSpeed, float *pPeekCurrent)
{
    /* Rotation speed */
    *pRotationSpeed = ((g_st_foc.st_sc.f4_speed_rad * 60.0) / MTR_TWOPI) / (float) com_u2_mtr_pp;
    
    /* Peak current */
    *pPeekCurrent = g_current;
    g_current = 0;
}
/**********************************************************************************************************************
* End of function fGetMotorData
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fSendFtdi
* Description  : Send data to FTDI device with MPSSE interface
* Arguments    : uint8_t *pSendBuffer : Pointer to send data
*                uint16_t Size        : send byte size
* Return Value : none
*********************************************************************************************************************/
static void fSendFtdi (uint8_t *pSendBuffer, uint16_t Size)
{
    /* Set transfer source start address */
    DMAC0.DMSAR = (void *) pSendBuffer;

    /* Set number of transfer operation */
    DMAC0.DMCRA = Size;

    /* Start DMA transfer*/
    R_Config_DMAC0_Start();

    /* Start SCI8 transfer */
    gv_RspiSendStatus = 1;
    R_Config_SCI8_Serial_Send(pSendBuffer, Size);
}
/**********************************************************************************************************************
* End of function fSendFtdi
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fPcCommandRecv
* Description  : Analyze data received from PC
* Arguments    : none
* Return Value : none
*********************************************************************************************************************/
static void fPcCommandRecv (void)
{
    uint8_t Buff;
    uint8_t FuncVal;
    
    while (1)
    {
        FuncVal = fPcGetData( &Buff);
        if (0 == FuncVal)
        {
            break;
        }
        switch (gv_PcRecvStatus)
        {
            case 0:
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
                if (lc_Header[gv_PcRecvStatus] == Buff)
                {
                    if (0 == gv_PcRecvStatus)
                    {
                        gv_PcRecvTimer = 0;
                    }
                    /* To next step */
                    gv_PcRecvStatus++;
                }
                else
                {
                    if (lc_Header[0] == Buff)
                    {
                        gv_PcRecvStatus = 1;
                    }
                    else
                    {
                        /* To first step */
                        gv_PcRecvStatus = 0;
                    }
                }
            break;
            
            case 7:
                /* Start sampling */
                if (DEF_StartMonitor == Buff)
                {
                    /* Measurement not yet started */
                    if ((0 == gv_MonitorStatus) && (0 == gv_PcCommand))
                    {
                        /* Sampling start request */
                        gv_PcCommand = Buff;
                    }
                    /* To first step */
                    gv_PcRecvStatus = 0;
                }
                /* Stop sampling */
                else if (DEF_StopMonitor == Buff)
                {
                    /* Now measuring */
                    if (1 == gv_MonitorStatus)
                    {
                        /* Sampling stop request */
                        gv_PcCommand = Buff;
                    }
                    /* To first step */
                    gv_PcRecvStatus = 0;
                }
                else if (DEF_SetUpSampling == Buff)
                {
                    /* Measurement not yet started */
                    if (0 == gv_MonitorStatus)
                    {
                        /* To next step */
                        gv_PcRecvStatus++;
                    }
                    else
                    {
                        /* To first step */
                        gv_PcRecvStatus = 0;
                    }
                }
                else
                {
                    if (lc_Header[0] == Buff)
                    {
                        gv_PcRecvStatus = 1;
                    }
                    else
                    {
                        /* To first step */
                        gv_PcRecvStatus = 0;
                    }
                }
            break;
            
            case 8:
                gv_SamplingConditions.m_SamplingFrequency = Buff;
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 9:
                gv_SamplingConditions.m_SamplingFrequency |= ((uint16_t) Buff << 8);
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 10:
                gv_SamplingConditions.m_SamplingCount = Buff;
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 11:
                gv_SamplingConditions.m_SamplingCount |= ((uint16_t) Buff << 8);
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 12:
                gv_SamplingConditions.m_SamplingOverLap = Buff;
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 13:
                gv_SamplingConditions.m_SamplingOverLap |= ((uint16_t) Buff << 8);
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 14:
                gv_SamplingConditions.m_MovingAverageMaxCount = Buff;
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 15:
                gv_SamplingConditions.m_MovingAverageMaxCount |= ((uint16_t) Buff << 8);
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 16:
                gv_SamplingConditions.m_SamplingMode = Buff;
                /* To next step */
                gv_PcRecvStatus++;
            break;
            
            case 17:
                gv_SamplingConditions.m_SamplingMode |= ((uint16_t) Buff << 8);
                /* To next step */
                gv_PcRecvStatus = 0;
                
                if (DEF_MaxSamplingFrequency < gv_SamplingConditions.m_SamplingFrequency)
                {
                    gv_SamplingConditions.m_SamplingFrequency = DEF_MaxSamplingFrequency;
                }
                else if (DEF_MinSamplingFrequency > gv_SamplingConditions.m_SamplingFrequency)
                {
                    gv_SamplingConditions.m_SamplingFrequency = DEF_MinSamplingFrequency;
                }
                else
                {
                    /* No operation */
                }
                
                if (DEF_MaxSamplingCount < gv_SamplingConditions.m_SamplingCount)
                {
                    gv_SamplingConditions.m_SamplingCount = DEF_MaxSamplingCount;
                }
                else if (DEF_MinSamplingCount > gv_SamplingConditions.m_SamplingCount)
                {
                    gv_SamplingConditions.m_SamplingCount = DEF_MinSamplingCount;
                }
                else
                {
                    if ((DEF_SamplingCount128 != gv_SamplingConditions.m_SamplingCount)
                            && (DEF_SamplingCount256  != gv_SamplingConditions.m_SamplingCount)
                            && (DEF_SamplingCount512  != gv_SamplingConditions.m_SamplingCount)
                            && (DEF_SamplingCount1024 != gv_SamplingConditions.m_SamplingCount))
                    {
                        gv_SamplingConditions.m_SamplingCount = DEF_DefaultSamplingCount;
                    }
                }
                
                if (DEF_MaxOverlapSampling < gv_SamplingConditions.m_SamplingOverLap)
                {
                    gv_SamplingConditions.m_SamplingOverLap = DEF_MaxOverlapSampling;
                }
                else if (DEF_MinOverlapSampling > gv_SamplingConditions.m_SamplingOverLap)
                {
                    gv_SamplingConditions.m_SamplingOverLap = DEF_MinOverlapSampling;
                }
                else
                {
                    /* No operation */
                }
                
                if ((DEF_SamplingCount128 == gv_SamplingConditions.m_SamplingCount)
                        && (DEF_MaxOverlapSampling <= gv_SamplingConditions.m_SamplingOverLap))
                {
                    gv_SamplingConditions.m_SamplingCount = DEF_DefaultOverlapSampling;
                }
                
                if (DEF_MovingAverageMinCount > gv_SamplingConditions.m_MovingAverageMaxCount)
                {
                    gv_SamplingConditions.m_MovingAverageMaxCount = DEF_MovingAverageMinCount;
                }
                else if (DEF_MovingAverageMaxCount < gv_SamplingConditions.m_MovingAverageMaxCount)
                {
                    gv_SamplingConditions.m_MovingAverageMaxCount = DEF_MovingAverageMaxCount;
                }
                else
                {
                    /* No operation  */
                }
                
                gv_SamplingConditions.m_CheckSum = gv_SamplingConditions.m_SamplingFrequency;
                gv_SamplingConditions.m_CheckSum += gv_SamplingConditions.m_SamplingCount;
                gv_SamplingConditions.m_CheckSum += gv_SamplingConditions.m_SamplingOverLap;
                gv_SamplingConditions.m_CheckSum += gv_SamplingConditions.m_MovingAverageMaxCount;
                gv_SamplingConditions.m_CheckSum += gv_SamplingConditions.m_SamplingMode;
                
                fInitFft();
                
            break;
            
            default:
                /* To first step */
                gv_PcRecvStatus = 0;
            break;
        }
    }
    
    if (0 != gv_PcRecvStatus)
    {
        if (DEF_PcRecvTimeOut < gv_PcRecvTimer)
        {
            gv_PcRecvStatus = 0;
        }
        else
        {
            /* No operation */
        }
    }
    else
    {
        /* No operation */
    }
}
/**********************************************************************************************************************
* End of function fPcCommandRecv
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fPcGetData
* Description  : Processing of data received from PC
* Arguments    : uint8_t   *pBuff
* Return Value : uint8_t   status
*********************************************************************************************************************/
static uint8_t fPcGetData (uint8_t *pBuff)
{
    uint8_t RetVal = 0;
    
    /* Receive data is in ring buffer */
    if (gv_PcRecvRingBuffer.m_Read != gv_PcRecvRingBuffer.m_Write)
    {
        *pBuff = gv_PcRecvRingBuffer.m_RingData[gv_PcRecvRingBuffer.m_Read];
        RetVal = 1;
    
        /* Update read pointer  */
        gv_PcRecvRingBuffer.m_Read = (uint16_t) ((gv_PcRecvRingBuffer.m_Read + 1) & (DEF_PcRecvBuffSize - 1));
    }
    else
    {
        /* No operation */
    }
    
    return RetVal;
}
/**********************************************************************************************************************
* End of function fPcGetData
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fUpadteMovingAverage
* Description  : Moving average addition processing
* Arguments    : uint16_t AiInference(0 - 100)
* Return Value : none
*********************************************************************************************************************/
static void fUpadteMovingAverage (uint16_t AiInference)
{
    gv_MovingAverage.m_Sum -= gv_MovingAverage.m_AiInference[gv_MovingAverage.m_Count];
    gv_MovingAverage.m_Sum += AiInference;
    gv_MovingAverage.m_AiInference[gv_MovingAverage.m_Count] = AiInference;
    
    gv_MovingAverage.m_Count++;
    
    if (gv_MovingAverage.m_Count >= gv_MovingAverage.m_MaxCount)
    {
        gv_MovingAverage.m_Count = 0;
        gv_MovingAverage.m_BufferFull = 1;
    }
    else
    {
        /* No operation */
    }
}
/**********************************************************************************************************************
* End of function fUpadteMovingAverage
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fGetMovingAverage
* Description  : Return moving average result
* Arguments    : none
* Return Value : uint16_t Average : Moving average result (0.0 - 100.0)
*********************************************************************************************************************/
static float fGetMovingAverage (void)
{
    float Average;
    
    if (gv_MovingAverage.m_BufferFull)
    {
        Average = (float) gv_MovingAverage.m_Sum / (float) gv_MovingAverage.m_MaxCount;
    }
    else
    {
        Average = (float) gv_MovingAverage.m_Sum / (float) gv_MovingAverage.m_Count;
    }
    
    return Average;
}
/**********************************************************************************************************************
* End of function fGetMovingAverage
**********************************************************************************************************************/

/**********************************************************************************************************************
* Function Name: fGetSamplingMode
* Description  : Return the active sampling mode
* Arguments    : none
* Return Value : SamplingMode (1:ShuntCurrent)
*********************************************************************************************************************/
uint16_t fGetSamplingMode (void)
{
    return gv_SamplingConditions.m_SamplingMode;
}
/**********************************************************************************************************************
* End of function fGetSamplingMode
**********************************************************************************************************************/
