/**********************************************************************************************************************
 * DISCLAIMER
 * This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
 * other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
 * applicable laws, including copyright laws.
 * THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
 * THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
 * EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
 * SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO
 * THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
 * this software. By using this software, you agree to the additional terms and conditions found by accessing the
 * following link:
 * http://www.renesas.com/disclaimer
 *
 * Copyright (C) 2019 Renesas Electronics Corporation. All rights reserved.
 *********************************************************************************************************************/
/**********************************************************************************************************************
 * File Name    : MotionSensor.h
 * Version      : 1.0
 * Description  : Header for the e-AI inference sample program.
 *********************************************************************************************************************/
/**********************************************************************************************************************
 * History : DD.MM.YYYY Version  Description
 *         : 14.06.2019 1.00     First Release
 *********************************************************************************************************************/

/**********************************************************************************************************************
 Includes   <System Includes> , "Project Includes"
 *********************************************************************************************************************/
#include <stdint.h>

/**********************************************************************************************************************
 Macro definitions
 *********************************************************************************************************************/
#ifndef MotionSensor_H
#define MotionSensor_H

/* MCU general setting defines */
/* PCLKB(40MHz) */
#define DEF_PCLKB                   (40000000.0)

/* CMTn CLK */
#define DEF_CMT_CLK8                (DEF_PCLKB / 8.0)

/* Sensor sampling defines */
/* Sampling end frame */
#define DEF_FrameSamplingEnd1       (1)
#define DEF_FrameSamplingEnd2       (2)

/* Default sampling frequency (2000Hz) */
#define DEF_DefaultSamplingFrequency (2000)

/* Minimum sampling frequency (1000Hz) */
#define DEF_MinSamplingFrequency    (1000)

/* Maximum sampling frequency(8000Hz) */
#define DEF_MaxSamplingFrequency    (8000)

/* Default sampling count */
#define DEF_DefaultSamplingCount    (512)

/* Sampling count */
#define DEF_SamplingCount128        (128)
#define DEF_SamplingCount256        (256)
#define DEF_SamplingCount512        (512)
#define DEF_SamplingCount1024       (1024)

/* Maximum sampling count */
#define DEF_MaxSamplingCount        DEF_SamplingCount1024

/* Minimum sampling count */
#define DEF_MinSamplingCount        DEF_SamplingCount128

/* Default overlap size */
#define DEF_DefaultOverlapSampling  (64)

/* Minimum overlap size */
#define DEF_MinOverlapSampling      (16)

/* Maximum overlap size */
#define DEF_MaxOverlapSampling      (128)

/* No. of elements in bit reverse table when sampling count is 1024 */
#define DEF_FFT_NUM_BITREV          (240)

/* Sampling ring buffer size(set value to power of 2) */
#define DEF_SamplingRingBuffer      (1024)

/* PC communication defines */
/* Send data header byte size */
#define DEF_HeaderSize              (7)

/* Send command */
#define DEF_SendAdMonitor           (1)
#define DEF_SendFrequencyMonitor    (2)

/* Receive command  */
#define DEF_StartMonitor            (1)
#define DEF_StopMonitor             (2)
#define DEF_SetUpSampling           (3)

/* Serial receive buffer size (set value to power of 2) */
#define DEF_PcRecvBuffSize          (128)

/* Serial receive timeout time (1second)  */
#define DEF_PcRecvTimeOut           (100)

/* Moving average defines */
/* Moving average mininum count */
#define DEF_MovingAverageMinCount           (1)

/* Moving average maximum count */
#define DEF_MovingAverageMaxCount           (100)

/*  Defaut moving average  */
#define DEF_DefaultMovingAverageMaxCount    (20)

/* Sampling mode */
/* Shunt current sensing mode */
#define DEF_ShuntCurrentSampling    (1)

/**********************************************************************************************************************
Global Typedef definitions
*********************************************************************************************************************/
#pragma pack

typedef struct
{
    int16_t m_Ad0Value;
    int16_t m_Ad1Value;
    int16_t m_Ad2Value;
} ST_SamplingRingData;

typedef struct
{
    uint16_t            m_Write;
    uint16_t            m_Read;
    ST_SamplingRingData m_SamplingRingData[DEF_SamplingRingBuffer];
} ST_SamplingRingBuffer;

typedef struct
{
    float  m_FrequencySpectrum[3][DEF_SamplingCount128 / 2];
    float  m_RotationSpeed;
    float  m_PeekCurrent;
    int8_t m_AiResult;
    float  m_AiMovingAverage;
} ST_Sampling128;

typedef struct
{
    float  m_FrequencySpectrum[3][DEF_SamplingCount256 / 2];
    float  m_RotationSpeed;
    float  m_PeekCurrent;
    int8_t m_AiResult;
    float  m_AiMovingAverage;
} ST_Sampling256;

typedef struct
{
    float  m_FrequencySpectrum[3][DEF_SamplingCount512 / 2];
    float  m_RotationSpeed;
    float  m_PeekCurrent;
    int8_t m_AiResult;
    float  m_AiMovingAverage;
} ST_Sampling512;

typedef struct
{
    float  m_FrequencySpectrum[3][DEF_SamplingCount1024 / 2];
    float  m_RotationSpeed;
    float  m_PeekCurrent;
    int8_t m_AiResult;
    float  m_AiMovingAverage;
} ST_Sampling1024;

typedef struct
{
    uint8_t                                                                                                                                                                                                                                                              m_Header[DEF_HeaderSize];
    uint8_t                                                                                                                                                                                                                                                              m_Cmd;
    union
    {
        ST_SamplingRingData m_SamplingData;
        ST_Sampling128      m_Sampling128;
        ST_Sampling256      m_Sampling256;
        ST_Sampling512      m_Sampling512;
        ST_Sampling1024     m_Sampling1024;
    } UN_Sampling;
} ST_SamplingMonitor;

typedef struct
{
    uint16_t m_Write;
    uint16_t m_Read;
    uint8_t  m_RingData[DEF_PcRecvBuffSize];
} ST_PcRecvRingBuffer;

typedef struct
{
    uint16_t m_MaxCount;
    uint16_t m_BufferFull;
    uint16_t m_Count;
    uint32_t m_Sum;
    uint16_t m_AiInference[DEF_MovingAverageMaxCount];
} ST_MovingAverage;

typedef struct
{
    uint16_t m_SamplingFrequency;
    uint16_t m_SamplingCount;
    uint16_t m_SamplingOverLap;
    uint16_t m_MovingAverageMaxCount;
    uint16_t m_SamplingMode;
    uint32_t m_CheckSum;
} ST_SamplingConditions;

#pragma packoption

/**********************************************************************************************************************
 External global variables
 *********************************************************************************************************************/
extern ST_SamplingRingBuffer gv_SamplingRingBuffer;
extern uint16_t gv_RspiSendStatus;
extern uint8_t gv_RecvData;
extern ST_PcRecvRingBuffer gv_PcRecvRingBuffer;
extern float g_current;

/**********************************************************************************************************************
 Exported global functions
 *********************************************************************************************************************/
void MotionSensorInit (void);
void MotionSensorMonitor (void);
uint16_t fGetSamplingMode (void);

#endif
