/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2018 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : main.c
* Description : The main function and the processes of application layer
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 28.09.2018 1.00
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
#include <stdint.h>
#include <machine.h>
#include "main.h"
#include "iodefine.h"
/****** for ICS ******/
#include "ICS2_RX66T.h"
/*********************/
#include "r_mtr_board.h"
#include "r_mtr_common.h"
#include "r_mtr_ctrl_mcu.h"
#include "r_mtr_ctrl_mrssk.h"
#include "r_mtr_driver_access.h"
#include "r_mtr_foc_control_less_speed.h"
#include "r_mtr_ics.h"
#include "r_mtr_parameter.h"

/* for e-AI inference */
#include "r_cg_macrodriver.h"
#include "MotionSensor.h"

/***********************************************************************************************************************
* Private functions
***********************************************************************************************************************/
static void     board_ui(void);           /* Board user interface */
static void     ics_ui(void);             /* ICS (Analyzer) user interface */
static void     software_init(void);      /* Software initialize */

/***********************************************************************************************************************
* Private variables
***********************************************************************************************************************/
static uint8_t    u1_reset_req;           /* Reset request flag */

/***********************************************************************************************************************
* Global variables
***********************************************************************************************************************/
uint8_t     g_u1_motor_status;            /* Motor status */
uint16_t    g_u2_conf_hw   = 0x0008;      /* 0000000000001000b */
uint16_t    g_u2_conf_sw   = 0x0000;      /* 0000000000000000b */
uint16_t    g_u2_conf_tool = 0x0200;      /* 0000001000000000b */
uint8_t     gui_u1_active_gui;
uint16_t    g_u2_conf_sw_ver;

uint8_t     com_u1_sw_userif;             /* User interface switch */
uint8_t     g_u1_sw_userif;               /* User interface switch */
uint8_t     com_u1_mode_system;           /* System mode */
uint8_t     g_u1_mode_system;             /* System mode */
uint16_t    g_u2_max_speed_rpm;

/*** DTC table for ICS ***/
#pragma section DTCTBL
uint32_t dtc_table[256];
#pragma section
/*************************/

/***********************************************************************************************************************
* Function Name : main
* Description   : Initialization and main routine
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
void main(void)
{
clrpsw_i();                                       /* Interrupt disable */
    R_MTR_InitHardware();                         /* Initialize peripheral functions */
    R_MTR_InitBoardUi();                          /* Initialize peripheral functions for user interface */
    software_init();                              /* Initialize private global variables */
    R_MTR_InitControl(MTR_ID_A);                  /* Initialize motor FOC control by ID "MTR_ID_A" */

    /* Initialize ICS */
    ics2_init((void*)dtc_table, ICS_SCI6_PB0_PB1, ICS_INT_LEVEL, ICS_BRR, ICS_INT_MODE);

    /* Execute reset event */
    R_MTR_ExecEvent(MTR_EVENT_RESET, MTR_ID_A);

    /* System initialize for e-AI application */
    R_Systeminit();

setpsw_i();                                       /* Interrupt enable */
    R_MTR_ChargeCapacitor(MTR_ID_A);              /* Wait for charging capacitor */

    /* e-AI inference initialize */
    MotionSensorInit();
    
    /*** main routine ***/
    while (1)
    {
        /*** select user interfaces ***/
        if (g_u1_sw_userif != com_u1_sw_userif)
        {
            g_u1_sw_userif = com_u1_sw_userif;
            if (ICS_UI == g_u1_sw_userif)
            {
                g_u1_mode_system = g_u1_motor_status;
                R_MTR_SetUserifMode(MTR_DISABLE_AUTO_SET);
            }
            else
            {
                R_MTR_SetUserifMode(MTR_ENABLE_AUTO_SET);
            }
        }

        if (BOARD_UI == g_u1_sw_userif)
        {
            board_ui();                           /* User interface control routine */
        }
        else if (ICS_UI == g_u1_sw_userif)
        {
            ics_ui();                             /* User interface using ICS */
        }
        else
        {
            /* Do Nothing */
        }

        /* e-AI inference */
        MotionSensorMonitor();
                
        R_MTR_ClearWdt();                         /* Clear watch dog timer */
    }
} /* End of function main */

/***********************************************************************************************************************
* Function Name : board_ui
* Description   : User interface using board UI
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
static void board_ui(void)
{
    int16_t s2_temp;
    uint8_t u1_temp_sw_signal;
    uint16_t u2_temp_vr1_signal;

    /*======================*/
    /*     Mode control     */
    /*======================*/
    g_u1_motor_status = R_MTR_GetStatus(MTR_ID_A);            /* Get status of motor control system */

    switch (g_u1_motor_status)
    {
        case MTR_MODE_INACTIVE:

            u1_temp_sw_signal = get_sw1();
            if (MTR_FLG_SET == mtr_remove_sw_chattering(u1_temp_sw_signal, SW_ON)) /* Check SW1 */
            {
                R_MTR_ExecEvent(MTR_EVENT_ACTIVE, MTR_ID_A); /* Execute active event */
            }

        break;

        case MTR_MODE_ACTIVE:

            u1_temp_sw_signal = get_sw1();
            if (MTR_FLG_SET == mtr_remove_sw_chattering(u1_temp_sw_signal, SW_OFF)) /* Check SW1 */
            {
                R_MTR_ExecEvent(MTR_EVENT_INACTIVE, MTR_ID_A); /* Execute stop event */
            }

            /*=============================*/
            /*      Set speed reference    */
            /*=============================*/
            u2_temp_vr1_signal = get_vr1();
            s2_temp = u2_temp_vr1_signal - ADJUST_OFFSET;   /* Read speed reference from VR1 */

            /* Change VR1 A/D value to rotation speed command value of +1000 to +2000rpm */
            /* The area near the VR1 center is the dead zone.  */
            if(-200 >= s2_temp)
            {
                s2_temp = (int16_t)(((0.542f * (float)s2_temp) - 891) * (-1));
            }
            else if(200 <= s2_temp)
            {
                s2_temp = (int16_t)(0.542f * (float)s2_temp) + 891;
            }
            else
            {
                s2_temp = 0;
            }

            s2_temp = R_MTR_LimitAbs(s2_temp, g_u2_max_speed_rpm);
            R_MTR_SetSpeed(s2_temp); /* Set speed reference */

        break;

        case MTR_MODE_ERROR:

            /* check SW2 & reset request flag */
            u1_temp_sw_signal = get_sw2();
            if ((SW_OFF == u1_reset_req) && (MTR_FLG_SET == mtr_remove_sw_chattering(u1_temp_sw_signal, SW_ON)))
            {
                u1_reset_req = SW_ON;
            }
            else if ((SW_ON == u1_reset_req) && (MTR_FLG_SET == mtr_remove_sw_chattering(u1_temp_sw_signal, SW_OFF)))
            {
                u1_reset_req = SW_OFF;
                R_MTR_ExecEvent(MTR_EVENT_RESET, MTR_ID_A); /* Execute reset event */
            }
            else
            {
                /* Do nothing */
            }

        break;

        default:
            /* Do nothing */
        break;
    }
    /***** LED control *****/
    mtr_board_led_control(g_u1_motor_status);
} /* End of function board_ui */

/***********************************************************************************************************************
* Function Name : ics_ui
* Description   : User interface using ICS
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
static void ics_ui(void)
{
    uint8_t u1_temp;

    /*============================*/
    /*        Get ICS value       */
    /*============================*/
    mtr_set_com_variables();

    /*============================*/
    /*        Execute event       */
    /*============================*/
    u1_temp = com_u1_mode_system;

    if (g_u1_mode_system != u1_temp)
    {
        if (u1_temp >= MTR_SIZE_EVENT)
        {
            com_u1_mode_system = g_u1_mode_system;
        }
        else
        {
            g_u1_mode_system = u1_temp;
            R_MTR_ExecEvent(g_u1_mode_system, MTR_ID_A);
        }
    }

    g_u1_motor_status = R_MTR_GetStatus(MTR_ID_A);      /* Get status of motor control system */

    if (MTR_EVENT_RESET == g_u1_mode_system)
    {
        if (MTR_MODE_INACTIVE == g_u1_motor_status)
        {
            software_init();                            /* Initialize private global variables for reset event */
        }
        else if (MTR_MODE_ERROR == g_u1_motor_status)
        {
            g_u1_mode_system   = MTR_EVENT_ERROR;
            com_u1_mode_system = MTR_EVENT_ERROR;
        }
        else
        {
            /* Do nothing */
        }
    }

    /***** LED control *****/
    mtr_board_led_control(g_u1_motor_status);
} /* End of function ics_ui */

/***********************************************************************************************************************
* Function Name : software_init
* Description   : Initialize private global variables
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
static void software_init(void)
{
    g_u1_motor_status            = MTR_MODE_INACTIVE;
    g_u2_max_speed_rpm           = MTR_MAX_SPEED_RPM;
    g_u1_sw_userif               = CONFIG_DEFAULT_UI;
    g_u1_mode_system             = MTR_EVENT_INACTIVE;
    u1_reset_req                 = SW_OFF;

    R_MTR_InputBuffParamReset();
    if (ICS_UI == g_u1_sw_userif)
    {
        R_MTR_SetUserifMode(MTR_DISABLE_AUTO_SET);
    }
    else
    {
        R_MTR_SetUserifMode(MTR_ENABLE_AUTO_SET);
    }

    /* ICS variables initialization */
    com_u1_sw_userif             = CONFIG_DEFAULT_UI;
    com_u1_mode_system           = MTR_EVENT_INACTIVE;
    mtr_ics_variables_init();
} /* End of function software_init */
