/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2018 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_ctrl_rx66t.h
* Description : Definitions of MCU & inverter control layer for RX66T
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 28.09.2018 1.00
***********************************************************************************************************************/

/* Guard against multiple inclusion */
#ifndef R_MTR_CTRL_RX66T_H
#define R_MTR_CTRL_RX66T_H

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
#include "r_mtr_parameter.h"

/***********************************************************************************************************************
* Macro definitions
***********************************************************************************************************************/
#define     MTR_GPT                 (0)                 /* 0:MTU 1:GPT*/

#define     MTR_PWM_TIMER_FREQ      (160.0f)            /* PWM timer frequency [MHz] */
#define     MTR_CARRIER_FREQ        (20.0f)             /* Carrier wave frequency [kHz] */

#define     MTR_INT_DECIMATION      (0)                 /* Interrupt skipping number */
#define     MTR_CTRL_PERIOD         ((MTR_INT_DECIMATION + 1) / (MTR_CARRIER_FREQ * 1000))
                                                        /* Control period */
#define     MTR_CTRL_PERIOD_INV     (1.0f / (float)MTR_CTRL_PERIOD)
                                                        /* 1 / control period */
#define     MTR_CONTROL_FREQ        ((MTR_CARRIER_FREQ * 1000) / (MTR_INT_DECIMATION + 1))
                                                        /* Control frequency [Hz] */
#define     MTR_DEADTIME_SET        ((uint16_t)(MTR_DEADTIME * MTR_PWM_TIMER_FREQ))
                                                        /* Setting value of deadtime */

#define     MTR_AD_FREQ             (40.0f)             /* A/D frequency [MHz] */
#define     MTR_AD_SAMPLING_CYCLE   (6 + 39)            /* Scan start processing time(tD)
                                                           + sample-and-hold processing time(tSPLSH) [cycle] */
#define     MTR_AD_SAMPLING_TIME    (MTR_AD_SAMPLING_CYCLE / MTR_AD_FREQ)
                                                        /* A/D sampling time [us] */
#define     MTR_AD_TIME_SET         ((uint16_t)(MTR_PWM_TIMER_FREQ * MTR_AD_SAMPLING_TIME))
                                                        /* A/D sampling time for duty calculation */
#define     MTR_CARRIER_SET_BASE    ((uint16_t)(MTR_PWM_TIMER_FREQ * 1000 / MTR_CARRIER_FREQ / 2))
#define     MTR_CARRIER_SET         ((uint16_t)(MTR_CARRIER_SET_BASE + MTR_DEADTIME_SET))
                                                        /* Max setting value of carrier period */

#define     MTR_PORT_HALL_U         (PORTE.PIDR.BIT.B0) /* Input port of hall sensor(HU) */
#define     MTR_PORT_HALL_V         (PORTE.PIDR.BIT.B1) /* Input port of hall sensor(HV) */
#define     MTR_PORT_HALL_W         (PORTE.PIDR.BIT.B5) /* Input port of hall sensor(HW) */

#define     MTR_PORT_UP             (PORT7.PODR.BIT.B1) /* Output port of PWM timer(Up) */
#define     MTR_PORT_UN             (PORT7.PODR.BIT.B4) /* Output port of PWM timer(Un) */
#define     MTR_PORT_VP             (PORT7.PODR.BIT.B2) /* Output port of PWM timer(Vp) */
#define     MTR_PORT_VN             (PORT7.PODR.BIT.B5) /* Output port of PWM timer(Vn) */
#define     MTR_PORT_WP             (PORT7.PODR.BIT.B3) /* Output port of PWM timer(Wp) */
#define     MTR_PORT_WN             (PORT7.PODR.BIT.B6) /* Output port of PWM timer(Wn) */

#define     MTR_PORT_SW1            (PORT8.PIDR.BIT.B0) /* Input port of SW1 */
#define     MTR_PORT_SW2            (PORT8.PIDR.BIT.B1) /* Input port of SW2 */

#define     MTR_PORT_LED1           (PORTE.PODR.BIT.B3) /* Output port of LED1 */
#define     MTR_PORT_LED2           (PORTB.PODR.BIT.B7) /* Output port of LED2 */
#define     MTR_PORT_LED3           (PORTB.PODR.BIT.B3) /* Output port of LED3 */

#define     MTR_AD12BIT_DATA        (4095.0f)           /* A/D 12Bit data */
#define     MTR_CURRENT_SCALING     (MTR_CURRENT_RANGE / MTR_AD12BIT_DATA)
                                                        /* For current scaling */
#define     MTR_VDC_SCALING         (MTR_VDC_RANGE / MTR_AD12BIT_DATA)
                                                        /* For Vdc scaling */
#define     MTR_ADC_OFFSET          (0x7FF)             /* A/D offset */

#endif /* R_MTR_CTRL_RX66T_H */
