/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2018 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_interrupt.c
* Description : Interrupt Handlers
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 28.09.2018 1.00
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
#include <machine.h>
#include "iodefine.h"
#include "r_mtr_ics.h"
#include "r_mtr_foc_control_less_speed.h"
#include "r_mtr_driver_access.h"

/***********************************************************************************************************************
* Exported global variables
***********************************************************************************************************************/
mtr_foc_control_t g_st_foc;

/* Use in e-AI processing */
extern float g_current = 0;
extern void r_Config_SCI8_transmitend_interrupt(void);
extern void r_Config_SCI8_receiveerror_interrupt(void);

/***********************************************************************************************************************
* Function Name : mtr_over_current_interrupt
* Description   : POE interrupt
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_over_current_interrupt(vect = VECT_ICU_GROUPBL1))
static void mtr_over_current_interrupt(void)
{
    if (1 == ICU.GRPBL1.BIT.IS9)
    {
        mtr_over_current(&g_st_foc);
    }

    /* SCI8 TEI8 (transmit end) */
    if (1 == ICU.GRPBL1.BIT.IS24)
    {
        r_Config_SCI8_transmitend_interrupt();
    }

    /* SCI8 ERI8 (recieve error) */
    if (1 == ICU.GRPBL1.BIT.IS25)
    {
        r_Config_SCI8_receiveerror_interrupt();
    }

} /* End of function mtr_over_current_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_cmt0_interrupt
* Description   : CMT0 interrupt
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_cmt0_interrupt(vect = VECT_CMT0_CMI0))
static void mtr_cmt0_interrupt(void)
{
    R_MTR_AutoSetVariables();
    mtr_foc_interrupt_500us(&g_st_foc);
} /* End of function mtr_cmt0_interrupt */

/***********************************************************************************************************************
* Function Name : mtr_tciv4_interrupt
* Description   : MTU_TCIV4 interrupt
* Arguments     : None
* Return Value  : None
***********************************************************************************************************************/
#pragma interrupt (mtr_tciv4_interrupt(vect = VECT_PERIA_INTA208))
static void mtr_tciv4_interrupt(void)
{
    mtr_foc_interrupt_carrier(&g_st_foc);
    mtr_ics_interrupt_process();

    /* get peak current for e-AI process */
    if (g_current < g_st_foc.f4_iu_ad)
    {
        g_current = g_st_foc.f4_iu_ad;
    }
} /* End of function mtr_tciv4_interrupt */
