/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
* other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
* EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
* SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS
* SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
* this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2018 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/
/***********************************************************************************************************************
* File Name   : r_mtr_interrupt_timer.c
* Description : The interval interrupt handler
***********************************************************************************************************************/
/**********************************************************************************************************************
* History : DD.MM.YYYY Version
*         : 28.09.2018 1.00
***********************************************************************************************************************/

/***********************************************************************************************************************
* Includes <System Includes> , "Project Includes"
***********************************************************************************************************************/
/* Standard library headers */
#include <stdint.h>
#include <machine.h>
#include <math.h>

/* Main associated header file */
#include "r_mtr_foc_control_less_speed.h"

/* Project headers */
#include "r_mtr_common.h"
#include "r_mtr_ctrl_mcu.h"
#include "r_mtr_driver_access.h"
#include "r_mtr_parameter.h"
#include "r_mtr_pi_control.h"

/***********************************************************************************************************************
* Function Name : mtr_foc_interrupt_500us
* Description   : 500us interrupt handler of FOC control
* Arguments     : st_foc - The pointer to the FOC data structure
* Return Value  : None
***********************************************************************************************************************/
void mtr_foc_interrupt_500us(mtr_foc_control_t *st_foc)
{
    float f4_temp0;
    float f4_idq_ref[2];

    f4_idq_ref[0] = 0.0f;
    f4_idq_ref[1] = 0.0f;
setpsw_i();

    /*====================*/
    /*   Set reference    */
    /*====================*/
    if (MTR_MODE_ACTIVE == mtr_statemachine_get_status(&st_foc->st_stm))
    {
        /***** Decide direction *****/
        mtr_decide_direction(st_foc);

        /***** Sensor-less to open-loop *****/
        /* Filter for phase error */
        st_foc->f4_phase_err_rad_lpf = R_MTR_FirstOrderLpff(&st_foc->st_phase_err_lpf, st_foc->f4_phase_err_rad);

        /* LPF for speed */
        st_foc->f4_speed_lpf_rad = R_MTR_FirstOrderLpff(&st_foc->st_est_speed_lpf, st_foc->st_sc.f4_speed_rad);

        if ((MTR_CONTROL_SPEED | MTR_CONTROL_CURRENT) == st_foc->u2_ctrl_conf)
        {
            /* f4_temp0 : The absolute value of speed command [rad/s] */
            f4_temp0 = fabsf(st_foc->f4_speed_lpf_rad);
            if (f4_temp0 < st_foc->f4_id_up_speed_rad)
            {
                st_foc->u1_flag_down_to_ol = MTR_FLG_SET;
                st_foc->st_sc.f4_ref_speed_rad_ctrl = st_foc->f4_speed_lpf_rad;
            }
        }

        /***** Id, Iq, speed reference setting *****/
        switch (st_foc->u2_run_mode)
        {
            case MTR_MODE_INIT:
                if (MTR_FLG_SET == st_foc->u1_flag_offset_calc)
                {
                    st_foc->u2_run_mode = MTR_MODE_BOOT;
                }
            break;

            case MTR_MODE_BOOT:
                st_foc->st_sc.f4_ref_speed_rad_ctrl = mtr_set_speed_ref(st_foc);
                f4_idq_ref[1] = mtr_set_iq_ref(st_foc);
                f4_idq_ref[0] = mtr_set_id_ref(st_foc);
                if (MTR_ID_CONST == st_foc->u1_state_id_ref)
                {
                    st_foc->u2_run_mode = MTR_MODE_DRIVE;
                }
            break;

            case MTR_MODE_DRIVE:
                st_foc->st_sc.f4_ref_speed_rad_ctrl = mtr_set_speed_ref(st_foc);

                f4_idq_ref[1] = mtr_set_iq_ref(st_foc);
                f4_idq_ref[0] = mtr_set_id_ref(st_foc);

            break;

            default:
                /* Do Nothing */
            break;
        }

        st_foc->u1_flag_down_to_ol = MTR_FLG_CLR;

        if (MTR_FLG_SET == st_foc->u1_flux_weakening)
        {
            /* This function will over-write the dq-axis current command */
            if(st_foc->u1_enable_fluxwkn_flag)
            {
                R_FLUXWKN_SetVamax(&st_foc->st_fluxwkn, R_MOD_GetVamax(&st_foc->st_mod));
                R_FLUXWKN_Run(&st_foc->st_fluxwkn, st_foc->f4_speed_lpf_rad, &st_foc->st_cc.f4_id_ad, f4_idq_ref);
            }
        }

        st_foc->st_cc.f4_id_ref = f4_idq_ref[0];
        st_foc->st_cc.f4_iq_ref = f4_idq_ref[1];
        if (MTR_IQ_SPEED_PI_OUTPUT == st_foc->u1_state_iq_ref)
        {
            st_foc->u2_ctrl_conf |= MTR_CONTROL_SPEED;
        }
        else
        {
            st_foc->u2_ctrl_conf = MTR_CONTROL_CURRENT;
        }
    }
} /* End of function mtr_foc_interrupt_timer */
